// BOI 2005
// Task: CONVEX POLYGON
// Output checker
// Author: Ahto Truu

#include <cmath>
#include <algorithm>
#include <iostream>
#include <fstream>
#include <sstream>
#include <iomanip>
#include <string>
using namespace std;

const char *iname = "poly.in"; // input file name
const char *oname = "poly.out"; // output file name

const int MAXN = 1000; // max number of edges
const double PREC = 0.001; // required precision

int n; // number of edges of the polygon
int e[MAXN]; // required lengths of the edges
double x[MAXN], y[MAXN]; // coordinates of the vertices
double dx[MAXN], dy[MAXN]; // coordinates of the edge vectors
double f[MAXN]; // actual lengths of the edges

int main() {
    ifstream ifile(iname);
    ifstream ofile(oname);

    // read the input file
    // this is prepared by the jury, so we assume it's correct
    int n;
    ifile >> n;
    for (int i = 0; i < n; ++i)
        ifile >> e[i];
    sort(e, e + n);
    reverse(e, e + n);

    int s = 0;
    for (int i = 1; i < n; ++i)
        s += e[i];

    // now process the output file
    // this is from the contestant, so we have to check for errors
    char c;
    if (s > e[0]) {
        // there must be a solution, verify it
        for (int i = 0; i < n; ++i) {
            string s;
            if (!getline(ofile, s)) {
                cerr << "Unexpected end of file on line " << i + 1 << endl;
                return 1;
            }
            stringstream ss(s);
            if (!(ss >> x[i] >> y[i])) {
                cerr << "Invalid input '" << s << "' on line " << i + 1 << endl;
                return 1;
            }
            if (ss >> c) {
                cerr << "Extra characters at end of line " << i + 1 << endl;
                return 1;
            }
        }
        for (int i = 0; i < n; ++i) {
            dx[i] = x[i] - x[(i + 1) % n];
            dy[i] = y[i] - y[(i + 1) % n];
            f[i] = sqrt(dx[i] * dx[i] + dy[i] * dy[i]);
        }
        double d = dx[0] * dy[1] - dx[1] * dy[0];
        for (int i = 1; i < n; ++i) {
            double dd = dx[i] * dy[(i + 1) % n] - dx[(i + 1) % n] * dy[i];
            if (d * dd <= 0) {
                cerr << "Polygon is non-convex at point " << i + 1 << endl;
                return 2;
            }
        }
        sort(f, f + n);
        reverse(f, f + n);
        for (int i = 0; i < n; ++i)
            if (fabs(f[i] - e[i]) > PREC) {
                cerr << "Invalid edge length " << setprecision(15) << f[i] <<
                    " instead of " << e[i] << endl;
                return 3;
            }
    } else {
        // there's no solution
        string s;
        if (!getline(ofile, s)) {
            cerr << "Unexpected end of file" << endl;
            return 1;
        }
        if (s != "NO SOLUTION") {
            cerr << "Wrong answer '" << s << "'" << endl;
            return 4;
        }
    }
    if (ofile >> c) {
        cerr << "Extra lines at end of file" << endl;
        return 1;
    }
    cerr << "OK" << endl;

    return 0;
}
